pub struct UncheckedRelayDetails<'a>(pub(crate) &'a UncheckedRelay<'a>);Expand description
A view for lower-level details about a UncheckedRelay.
Most callers should avoid using this structure;
they should instead call higher-level functions
like those in the tor-relay-selection crate.
Tuple Fields
0: &'a UncheckedRelay<'a>Implementations
Sourceimpl<'a> UncheckedRelayDetails<'a>
impl<'a> UncheckedRelayDetails<'a>
Sourcepub fn is_suitable_as_guard(&self) -> bool
pub fn is_suitable_as_guard(&self) -> bool
Return true if this relay is suitable for use as a newly sampled guard, or for continuing to use as a guard.
Sourcepub fn is_dir_cache(&self) -> bool
pub fn is_dir_cache(&self) -> bool
Return true if this relay is a potential directory cache.