#[non_exhaustive]pub enum OnionDirLookupError {
WrongTimePeriod,
}Available on crate feature
hs-common only.Expand description
An error returned when looking up onion service directories.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.
WrongTimePeriod
We tried to look up an onion service directory for a time period that did not correspond to one of our hash rings.