pub enum Timeliness {
    Strict,
    Timely,
    Unchecked,
}
How “timely” must a network directory be?

This enum is used as an argument when requesting a NetDir object from NetDirProvider and other APIs, to specify how recent the information must be in order to be useful.

Variants



Strict

The network directory must be strictly timely.

That is, it must be based on a consensus that valid right now, with no tolerance for skew or consensus problems.

Avoid using this option if you could use Timeliness::Timely instead.



Timely

The network directory must be roughly timely.

This is, it must be be based on a consensus that is not too far in the future, and not too far in the past.

(The tolerances for “too far” will depend on configuration.)

This is almost always the option that you want to use.



Unchecked

Any network directory is permissible, regardless of how untimely.

Avoid using this option if you could use Timeliness::Timely instead.