#[non_exhaustive]
pub enum WeightRole {
    Guard,
    Middle,
    Exit,
    BeginDir,
    Unweighted,
}
Possible ways to weight relays when selecting them a random.

Relays are weighted by a function of their bandwidth that depends on how scarce that “kind” of bandwidth is. For example, if Exit bandwidth is rare, then Exits should be less likely to get chosen for the middle hop of a path.

Variants (Non-exhaustive)

This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.


Guard

Selecting a relay to use as a guard



Middle

Selecting a relay to use as a middle relay in a circuit.



Exit

Selecting a relay to use to deliver traffic to the internet.



BeginDir

Selecting a relay for a one-hop BEGIN_DIR directory request.



Unweighted

Selecting a relay with no additional weight beyond its bandwidth.