fn find_params_for_time(
info: &[(SharedRandVal, Range<SystemTime>)],
period: TimePeriod,
) -> Result<Option<HsDirParams>>Expand description
Given a list of SrvInfo, return an HsRingParams instance for a given time period, if possible.
fn find_params_for_time(
info: &[(SharedRandVal, Range<SystemTime>)],
period: TimePeriod,
) -> Result<Option<HsDirParams>>Given a list of SrvInfo, return an HsRingParams instance for a given time period, if possible.