fn srv_interval(consensus: &MdConsensus) -> DurationExpand description
Return the length of time for which a single SRV value is valid.
fn srv_interval(consensus: &MdConsensus) -> DurationReturn the length of time for which a single SRV value is valid.