type SrvInfo = (SharedRandVal, Range<SystemTime>);Expand description
Helper type: A SharedRandVal, and the time range over which it is the most
recent.
type SrvInfo = (SharedRandVal, Range<SystemTime>);Helper type: A SharedRandVal, and the time range over which it is the most
recent.