pub(crate) struct HsDirIndex([u8; 32]);Expand description
A sort key determining a position in the onion service directory ring.
This is either the sort key of a given relay at a given time period, or the sort key for a probing position for a given onion service id at a given time.
The specification calls this an “index” but HsDirIndex is a key-length
sized, apparently-random, value, which determines the ordering of relays on
the ring. It is not the position number (ie, not a dense index starting at
0).
Note that this is not an index into any array; it is instead an index into a space of possible values in a (virtual!) ring of 2^256 elements.
Tuple Fields
0: [u8; 32]Trait Implementations
Sourceimpl Clone for HsDirIndex
impl Clone for HsDirIndex
Sourcefn clone(&self) -> HsDirIndex
fn clone(&self) -> HsDirIndex
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for HsDirIndex
impl Debug for HsDirIndex
Sourceimpl Hash for HsDirIndex
impl Hash for HsDirIndex
Sourceimpl Ord for HsDirIndex
impl Ord for HsDirIndex
Sourcefn cmp(&self, other: &HsDirIndex) -> Ordering
fn cmp(&self, other: &HsDirIndex) -> Ordering
1.21.0 (const: unstable) · Sourcefn max(self, other: Self) -> Selfwhere
Self: Sized,
fn max(self, other: Self) -> Selfwhere
Self: Sized,
Compares and returns the maximum of two values. Read more
Sourceimpl PartialEq for HsDirIndex
impl PartialEq for HsDirIndex
Sourcefn eq(&self, other: &HsDirIndex) -> bool
fn eq(&self, other: &HsDirIndex) -> bool
Tests for
self and other values to be equal, and is used by ==.Sourceimpl PartialOrd for HsDirIndex
impl PartialOrd for HsDirIndex
impl Copy for HsDirIndex
impl Eq for HsDirIndex
impl StructuralPartialEq for HsDirIndex