pub(crate) struct HsDirPos(usize);Expand description
Position in the hsdir hash ring
This an “index” in the sense that you can use it to index HsDirRing.ring,
but in the spec, in the context of the hsdir,
“index” is used to the sort key - here, HsDirIndex.
Tuple Fields
0: usizeTrait Implementations
Sourceimpl Ord for HsDirPos
impl Ord for HsDirPos
1.21.0 (const: unstable) · Sourcefn max(self, other: Self) -> Selfwhere
Self: Sized,
fn max(self, other: Self) -> Selfwhere
Self: Sized,
Compares and returns the maximum of two values. Read more
Sourceimpl PartialOrd for HsDirPos
impl PartialOrd for HsDirPos
impl Copy for HsDirPos
impl Eq for HsDirPos
impl StructuralPartialEq for HsDirPos