pub struct HsDirParams {
pub(crate) time_period: TimePeriod,
pub(crate) shared_rand: SharedRandVal,
pub(crate) srv_lifespan: Range<SystemTime>,
}Expand description
Parameters for generating and using an HsDir ring.
These parameters are derived from the shared random values and time parameters in the consensus, and are used to determine the position of each HsDir within the ring.
Fields
time_period: TimePeriodThe time period for this ring. It’s used to ensure that blinded onion keys rotate in a predictable way over time.
The SharedRandVal for this ring. It’s used to ensure that the position of each HsDir within the ring rotates unpredictably over time.
srv_lifespan: Range<SystemTime>The range of times over which the srv is most current.
Implementations
Sourceimpl HsDirParams
impl HsDirParams
Sourcepub fn time_period(&self) -> TimePeriod
pub fn time_period(&self) -> TimePeriod
Return the time period for which these parameters are valid.
The hs_blind_id for an onion service changes every time period: when
uploading, callers should use this time period to determine which
hs_blind_id’s descriptor should be sent to which directory.
Sourcepub fn start_of_shard_rand_period(&self) -> SystemTime
pub fn start_of_shard_rand_period(&self) -> SystemTime
Return the starting time for the shared-random-value protocol that produced the SRV for this time period.
Sourcepub fn offset_within_srv_period(
&self,
when: SystemTime,
) -> Option<SrvPeriodOffset>
pub fn offset_within_srv_period( &self, when: SystemTime, ) -> Option<SrvPeriodOffset>
Return an opaque offset for when from the start of the shared-random-value protocol
period corresponding to the SRV for this time period.
When uploading, callers should this offset to determine the revision counter for their descriptors.
Returns None if when is after the start of the SRV period.
Sourcepub(crate) fn compute(
consensus: &MdConsensus,
params: &NetParameters,
) -> Result<HsDirs<HsDirParams>>
pub(crate) fn compute( consensus: &MdConsensus, params: &NetParameters, ) -> Result<HsDirs<HsDirParams>>
Compute the HsDirParams for the current time period, according to a given
consensus.
rend-spec-v3 section 2.2.1 et seq
Return the ring parameters for the current period (which clients use when fetching onion service descriptors), along with a Vec of ring parameters for any secondary periods that onion services should additionally use when publishing their descriptors.
Note that “current” here is always relative to a given consensus, not the current wall-clock time.
(This function’s return type is a bit cumbersome; these parameters are bundled together because it is efficient to compute them all at once.)
Note that this function will only return an error if something is extremely wrong with the provided consensus: for other error cases, it returns a “disaster fallback”.