Struct tor_netdir::RelayWeight
source · pub struct RelayWeight(_);Expand description
An opaque type representing the weight with which a relay or set of relays will be selected for a given role.
Most users should ignore this type, and just use pick_relay instead.
Implementations
sourceimpl RelayWeight
impl RelayWeight
sourcepub fn checked_div(&self, rhs: RelayWeight) -> Option<f64>
pub fn checked_div(&self, rhs: RelayWeight) -> Option<f64>
Try to divide this weight by rhs.
Return a ratio on success, or None on division-by-zero.
sourcepub fn ratio(&self, frac: f64) -> Option<RelayWeight>
pub fn ratio(&self, frac: f64) -> Option<RelayWeight>
Compute a ratio frac of this weight.
Return None if frac is less than zero, since negative weights are impossible.