pub(crate) struct RouterStatusIdx(pub(crate) usize);Expand description
Index into the consensus relays
This is an index into the list of relays returned by
.c_relays()
(on the corresponding consensus or netdir).
This is just a usize inside, but using a newtype prevents getting a relay index
confused with other kinds of slice indices or counts.
If you are in a part of the code which needs to work with multiple consensuses, the typechecking cannot tell if you try to index into the wrong consensus.
Tuple Fields
0: usizeTrait Implementations
Sourceimpl Clone for RouterStatusIdx
impl Clone for RouterStatusIdx
Sourcefn clone(&self) -> RouterStatusIdx
fn clone(&self) -> RouterStatusIdx
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for RouterStatusIdx
impl Debug for RouterStatusIdx
Sourceimpl From<RouterStatusIdx> for usize
impl From<RouterStatusIdx> for usize
Sourcefn from(value: RouterStatusIdx) -> Self
fn from(value: RouterStatusIdx) -> Self
Converts to this type from the input type.
Sourceimpl From<usize> for RouterStatusIdx
impl From<usize> for RouterStatusIdx
Sourceimpl Hash for RouterStatusIdx
impl Hash for RouterStatusIdx
Sourceimpl Ord for RouterStatusIdx
impl Ord for RouterStatusIdx
Sourcefn cmp(&self, other: &RouterStatusIdx) -> Ordering
fn cmp(&self, other: &RouterStatusIdx) -> Ordering
1.21.0 (const: unstable) · Sourcefn max(self, other: Self) -> Selfwhere
Self: Sized,
fn max(self, other: Self) -> Selfwhere
Self: Sized,
Compares and returns the maximum of two values. Read more
Sourceimpl PartialEq for RouterStatusIdx
impl PartialEq for RouterStatusIdx
Sourcefn eq(&self, other: &RouterStatusIdx) -> bool
fn eq(&self, other: &RouterStatusIdx) -> bool
Tests for
self and other values to be equal, and is used by ==.Sourceimpl PartialOrd for RouterStatusIdx
impl PartialOrd for RouterStatusIdx
impl Copy for RouterStatusIdx
impl Eq for RouterStatusIdx
impl StructuralPartialEq for RouterStatusIdx