pub struct SubnetConfig { /* private fields */ }
Configuration for determining when two relays have addresses “too close” in the network.

Used by Relay::in_same_subnet().

Implementations

Construct a new SubnetConfig from a pair of bit prefix lengths.

The values are clamped to the appropriate ranges if they are out-of-bounds.

Return true if the two addresses in the same subnet, according to this configuration.

Return true if any of the addresses in a shares a subnet with any of the addresses in b, according to this configuration.