pub struct UncheckedRelay<'a> { /* private fields */ }
A relay that we haven’t checked for validity or usability in routing.

Implementations

Return true if this relay is valid and usable.

This function should return true for every Relay we expose to the user.

If this is usable, return a corresponding Relay object.

Return true if this relay has the guard flag.

Return true if this relay is a potential directory cache.