pub struct TestNetDirProvider { /* private fields */ }
Available on crate feature testing only.
Helper implementation of a NetDirProvider.

A TestNetDirProvider can be used to provide a netdir in a single situation that requires a NetDirProvider. It does not yet notify its owner of any changes; it only provides a NetDir.

Implementations

Create a new TestNetDirProvider with no netdir available.

Replace the NetDir in this TestNetDirProvider.