pub trait MdReceiver {
// Required methods
fn missing_microdescs(&self) -> Box<dyn Iterator<Item = &MdDigest> + '_>;
fn add_microdesc(&mut self, md: MicrodescAndHash) -> bool;
fn n_missing(&self) -> usize;
}Expand description
A partial or full network directory that we can download microdescriptors for.
Required Methods
Sourcefn missing_microdescs(&self) -> Box<dyn Iterator<Item = &MdDigest> + '_>
fn missing_microdescs(&self) -> Box<dyn Iterator<Item = &MdDigest> + '_>
Return an iterator over the digests for all of the microdescriptors that this netdir is missing.
Sourcefn add_microdesc(&mut self, md: MicrodescAndHash) -> bool
fn add_microdesc(&mut self, md: MicrodescAndHash) -> bool
Add a microdescriptor to this netdir, if it was wanted.
Return true if it was indeed wanted.
Dyn Compatibility
This trait is dyn compatible.
In older versions of Rust, dyn compatibility was called "object safety".