enum BandwidthFn {
Uniform,
IncludeUnmeasured,
MeasuredOnly,
}Expand description
Internal: how should we find the base bandwidth of each relay? This value is global over a whole directory, and depends on the bandwidth weights in the consensus.
Variants
Uniform
There are no weights at all in the consensus: weight every relay as 1.
IncludeUnmeasured
There are no measured weights in the consensus: count unmeasured weights as the weights for relays.
MeasuredOnly
There are measured relays in the consensus; only use those.
Implementations
Sourceimpl BandwidthFn
impl BandwidthFn
Sourcefn apply(&self, w: &RelayWeight) -> u32
fn apply(&self, w: &RelayWeight) -> u32
Apply this function to the measured or unmeasured bandwidth of a single relay.