fn pick_bandwidth_fn<'a, I>(weights: I) -> BandwidthFnExpand description
Helper: Calculate the function we should use to find initial relay bandwidths.
fn pick_bandwidth_fn<'a, I>(weights: I) -> BandwidthFnHelper: Calculate the function we should use to find initial relay bandwidths.