pub(crate) struct WeightSet {
bandwidth_fn: BandwidthFn,
shift: u8,
w: [RelayWeight; 8],
}Expand description
Information derived from a consensus to use when picking relays by weighted bandwidth.
Fields
bandwidth_fn: BandwidthFnHow to find the bandwidth to use when picking a relay by weighted bandwidth.
(This tells us us whether to count unmeasured relays, whether to look at bandwidths at all, etc.)
shift: u8Number of bits that we need to right-shift our weighted products so that their sum won’t overflow u64::MAX.
w: [RelayWeight; 8]A set of RelayWeight values, indexed by WeightKind::idx, used
to weight different kinds of relays.
Implementations
Sourceimpl WeightSet
impl WeightSet
Sourcepub(crate) fn weight_rs_for_role(
&self,
rs: &MdRouterStatus,
role: WeightRole,
) -> u64
pub(crate) fn weight_rs_for_role( &self, rs: &MdRouterStatus, role: WeightRole, ) -> u64
Find the actual 64-bit weight to use for a given routerstatus when considering it for a given role.
NOTE: This function does not consider whether the relay in question
actually matches the given role. For example, if role is Guard
we don’t check whether or not rs actually has the Guard flag.
Sourcefn weight_bw_for_role(
&self,
kind: WeightKind,
relay_weight: &RelayWeight,
role: WeightRole,
) -> u64
fn weight_bw_for_role( &self, kind: WeightKind, relay_weight: &RelayWeight, role: WeightRole, ) -> u64
Find the 64-bit weight to report for a relay of kind whose weight in
the consensus is relay_weight when using it for role.
Sourcepub(crate) fn from_consensus(
consensus: &MdConsensus,
params: &NetParameters,
) -> Self
pub(crate) fn from_consensus( consensus: &MdConsensus, params: &NetParameters, ) -> Self
Compute the correct WeightSet for a provided MdConsensus.
Sourcefn from_parts(
bandwidth_fn: BandwidthFn,
total_bw: u64,
weight_scale: u32,
p: &NetParams<i32>,
) -> Self
fn from_parts( bandwidth_fn: BandwidthFn, total_bw: u64, weight_scale: u32, p: &NetParams<i32>, ) -> Self
Compute the correct WeightSet given a bandwidth function, a weight-scaling parameter, a total amount of bandwidth for all relays in the consensus, and a set of bandwidth parameters.
Sourcefn validate(self, consensus: &MdConsensus) -> Self
fn validate(self, consensus: &MdConsensus) -> Self
Assert that we have correctly computed our shift values so that our total weighted bws do not exceed u64::MAX.