pub struct PartialNetDir { /* private fields */ }
A partially build NetDir – it can’t be unwrapped until it has enough information to build safe paths.

Implementations

Create a new PartialNetDir with a given consensus, and no microdescriptors loaded.

If replacement_params is provided, override network parameters from the consensus with those from replacement_params.

Return the declared lifetime of this PartialNetDir.

Fill in as many missing microdescriptors as possible in this netdir, using the microdescriptors from the previous netdir.

Return true if this are enough information in this directory to build multihop paths.

If this directory has enough information to build multihop circuits, return it.