Struct tor_netdir::Relay

source ·
pub struct Relay<'a> { /* private fields */ }
A view of a relay on the Tor network, suitable for building circuits.

Implementations

Return the Ed25519 ID for this relay.

Return the RsaIdentity for this relay.

Return true if this relay and other seem to be the same relay.

(Two relays are the same if they have the same identity.)

Return true if this relay allows exiting to port on IPv4.

Return true if this relay allows exiting to port on IPv6.

Return true if this relay is suitable for use as a directory cache.

Return true if this relay is marked as usable as a new Guard node.

Return true if both relays are in the same subnet, as configured by subnet_config.

Two relays are considered to be in the same subnet if they have IPv4 addresses with the same subnets_family_v4-bit prefix, or if they have IPv6 addresses with the same subnets_family_v6-bit prefix.

Return true if both relays are in the same family.

(Every relay is considered to be in the same family as itself.)

Return true if there are any ports for which this Relay can be used for exit traffic.

(Returns false if this relay doesn’t allow exit traffic, or if it has been flagged as a bad exit.)

Return the IPv4 exit policy for this relay. If the relay has been marked BadExit, return an empty policy

Return the IPv6 exit policy for this relay. If the relay has been marked BadExit, return an empty policy

Return the IPv4 exit policy declared by this relay. Contrary to Relay::ipv4_policy, this does not verify if the relay is marked BadExit.

Return the IPv6 exit policy declared by this relay. Contrary to Relay::ipv6_policy, this does not verify if the relay is marked BadExit.

Available on crate feature experimental-api only.

Return a reference to this relay’s “router status” entry in the consensus.

The router status entry contains information about the relay that the authorities voted on directly. For most use cases, you shouldn’t need them.

This function is only available if the crate was built with its experimental-api feature.

Available on crate feature experimental-api only.

Return a reference to this relay’s “microdescriptor” entry in the consensus.

A “microdescriptor” is a synopsis of the information about a relay, used to determine its capabilities and route traffic through it. For most use cases, you shouldn’t need it.

This function is only available if the crate was built with its experimental-api feature.