Struct tor_netdir::SubnetConfig
source · pub struct SubnetConfig { /* private fields */ }Expand description
Configuration for determining when two relays have addresses “too close” in the network.
Used by Relay::in_same_subnet().
Implementations
sourceimpl SubnetConfig
impl SubnetConfig
sourcepub fn new(subnets_family_v4: u8, subnets_family_v6: u8) -> Self
pub fn new(subnets_family_v4: u8, subnets_family_v6: u8) -> Self
Construct a new SubnetConfig from a pair of bit prefix lengths.
The values are clamped to the appropriate ranges if they are out-of-bounds.
sourcepub fn addrs_in_same_subnet(&self, a: &IpAddr, b: &IpAddr) -> bool
pub fn addrs_in_same_subnet(&self, a: &IpAddr, b: &IpAddr) -> bool
Return true if the two addresses in the same subnet, according to this configuration.