Struct tor_netdir::UncheckedRelay
source · pub struct UncheckedRelay<'a> { /* private fields */ }Expand description
A relay that we haven’t checked for validity or usability in routing.
Implementations
sourceimpl<'a> UncheckedRelay<'a>
impl<'a> UncheckedRelay<'a>
sourcepub fn is_usable(&self) -> bool
pub fn is_usable(&self) -> bool
Return true if this relay is valid and usable.
This function should return true for every Relay we expose
to the user.
sourcepub fn into_relay(self) -> Option<Relay<'a>>
pub fn into_relay(self) -> Option<Relay<'a>>
If this is usable, return a corresponding Relay object.
sourcepub fn is_flagged_guard(&self) -> bool
pub fn is_flagged_guard(&self) -> bool
Return true if this relay has the guard flag.
sourcepub fn is_dir_cache(&self) -> bool
pub fn is_dir_cache(&self) -> bool
Return true if this relay is a potential directory cache.